==> seedsui-react-5.1.6.tgz: package/es/InputDate/InputDateRange.js <==
var _excluded = ["rangeProps", "value", "type", "startProps", "endProps", "onError", "onChange", "onClick", "children"];

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

// require PrototypeDate.js和PrototypeString.js
import React, { useState, Fragment, forwardRef, useRef, useImperativeHandle } from 'react';
import InputText from './../InputText';
import DateRange from './../DatePopover/DateRange';
import helper from './helper';
var InputDateRange = forwardRef(function (_ref, ref) {
  var _ref$rangeProps = _ref.rangeProps,
      rangeProps = _ref$rangeProps === void 0 ? {
    // 标题
    caption: '',
    // 分割线
    separator: ''
  } : _ref$rangeProps,
      value = _ref.value,
      _ref$type = _ref.type,
      type = _ref$type === void 0 ? 'date-range' : _ref$type,
      _ref$startProps = _ref.startProps,
      startProps = _ref$startProps === void 0 ? {} : _ref$startProps,
      _ref$endProps = _ref.endProps,
      endProps = _ref$endProps === void 0 ? {} : _ref$endProps,
      onError = _ref.onError,
      onChange = _ref.onChange,
      onClick = _ref.onClick,
      children = _ref.children,
      others = _objectWithoutPropertiesLoose(_ref, _excluded);

  var _useState = useState(false),
      rangeVisible = _useState[0],
      setRangeVisible = _useState[1];

  var inputTextRef = useRef(null);
  useImperativeHandle(ref, function () {
    return inputTextRef.current;
  }); // 类型修改

  type = type.replace('-range', ''); // 开始和结束时间

  var start = null;
  var end = null;

  if (Array.isArray(value) && value.length === 2) {
    start = value[0];
    end = value[1];
  }

  var displayValue = '';

  if (start && end && typeof start === 'string' && typeof end === 'string') {
    displayValue = "" + start + (rangeProps.separator || '~') + end;
  } // 点击文本框


  function handleClickInput() {
    if (onClick) onClick.apply(void 0, arguments);
    if (others.readOnly) return;
    setRangeVisible(true);
  } // 选择校验


  function handleValidate(e, values) {
    if (inputTextRef.current) e.currentTarget = inputTextRef.current;
    var newValue = helper.validateRange(values, onError);
    if (newValue === false) return false;
    return true;
  } // 开始时间和结束时间


  function handleChange(e, values) {
    if (inputTextRef.current) e.currentTarget = inputTextRef.current;

    if (onChange) {
      onChange(e, values);
    }
  }

  return /*#__PURE__*/React.createElement(Fragment, null, children && /*#__PURE__*/React.createElement("div", _extends({
    ref: inputTextRef
  }, others, {
    onClick: handleClickInput
  }), children), !children && /*#__PURE__*/React.createElement(InputText, _extends({
    ref: inputTextRef
  }, others, {
    value: displayValue,
    type: "text",
    readOnly: true,
    onClick: handleClickInput
  })), /*#__PURE__*/React.createElement(DateRange, {
    caption: rangeProps.caption,
    visible: rangeVisible,
    type: type,
    startProps: startProps,
    endProps: endProps,
    start: start,
    end: end,
    onSubmitBefore: handleValidate,
    onChange: handleChange,
    onVisibleChange: setRangeVisible
  }));
});
export default InputDateRange;

==> seedsui-react-5.5.1.tgz: package/es/InputDate/InputDateRange.js <==
var _excluded = ["rangeProps", "value", "type", "startInputDateProps", "endInputDateProps", "onChange", "onClick", "children"];

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

// require PrototypeDate.js和PrototypeString.js
import React, { useState, Fragment, forwardRef, useRef, useImperativeHandle } from 'react';
import InputText from './../InputText';
import DateRange from './../DateRangePopover/DateRange';
var InputDateRange = forwardRef(function (_ref, ref) {
  var _ref$rangeProps = _ref.rangeProps,
      rangeProps = _ref$rangeProps === void 0 ? {
    // 标题
    caption: '',
    // 分割线
    separator: ''
  } : _ref$rangeProps,
      value = _ref.value,
      _ref$type = _ref.type,
      type = _ref$type === void 0 ? 'date-range' : _ref$type,
      _ref$startInputDatePr = _ref.startInputDateProps,
      startInputDateProps = _ref$startInputDatePr === void 0 ? {} : _ref$startInputDatePr,
      _ref$endInputDateProp = _ref.endInputDateProps,
      endInputDateProps = _ref$endInputDateProp === void 0 ? {} : _ref$endInputDateProp,
      onChange = _ref.onChange,
      onClick = _ref.onClick,
      children = _ref.children,
      others = _objectWithoutPropertiesLoose(_ref, _excluded);

  var _useState = useState(false),
      rangeVisible = _useState[0],
      setRangeVisible = _useState[1];

  var inputTextRef = useRef(null);
  useImperativeHandle(ref, function () {
    return inputTextRef.current;
  }); // 类型修改

  type = type.replace('-range', ''); // 开始和结束时间

  var start = null;
  var end = null;

  if (Array.isArray(value) && value.length === 2) {
    start = value[0];
    end = value[1];
  }

  var displayValue = ''; // 允许仅选中开始或者结束

  if ((start || end) && (typeof start === 'string' || typeof end === 'string')) {
    displayValue = "" + (start || '') + (rangeProps.separator || '~') + (end || '');
  } // 点击文本框


  function handleClickInput() {
    if (onClick) onClick.apply(void 0, arguments);
    if (others.readOnly) return;
    setRangeVisible(true);
  } // 开始时间和结束时间


  function handleChange(e, values) {
    if (inputTextRef.current) e.currentTarget = inputTextRef.current;

    if (onChange) {
      onChange(e, values);
    }
  }

  return /*#__PURE__*/React.createElement(Fragment, null, children && /*#__PURE__*/React.createElement("div", _extends({
    ref: inputTextRef
  }, others, {
    onClick: handleClickInput
  }), children), !children && /*#__PURE__*/React.createElement(InputText, _extends({
    ref: inputTextRef
  }, others, {
    value: displayValue,
    type: "text",
    readOnly: true,
    onClick: handleClickInput
  })), /*#__PURE__*/React.createElement(DateRange, {
    caption: rangeProps.caption,
    visible: rangeVisible,
    type: type,
    startInputDateProps: startInputDateProps,
    endInputDateProps: endInputDateProps,
    start: start,
    end: end,
    onChange: handleChange,
    onVisibleChange: setRangeVisible
  }));
});
export default InputDateRange;
